@@ -6,8 +6,8 @@ import fsspec
 import nbproject
 import pandas as pd
 import readfcs
-from cloudpathlib import CloudPath
-from lndb_setup import settings
+from lndb import settings
+from lndb.dev import UPath
 
 from ._h5ad import read_adata_h5ad
 from ._zarr import read_adata_zarr
@@ -20,8 +20,6 @@ READER_FUNCS = {
     ".zarr": read_adata_zarr,
 }
 
-fsspec_filesystem = None
-
 
 def print_hook(size, value, **kwargs):
     progress = value / size
@@ -42,35 +40,36 @@ class ProgressCallback(fsspec.callbacks.Callback):
         return None
 
 
-def store_file(
-    localfile: Union[str, Path], storagekey: str, use_fsspec: bool = False
-) -> float:
-    """Store arbitrary file.
+def store_object(localpath: Union[str, Path], storagekey: str) -> float:
+    """Store arbitrary file to configured storage location.
 
     Returns size in bytes.
     """
     storagepath = settings.instance.storage.key_to_filepath(storagekey)
-    global fsspec_filesystem
-    if isinstance(storagepath, CloudPath):
-        if use_fsspec:
-            if fsspec_filesystem is None:
-                fsspec_filesystem = fsspec.filesystem(
-                    storagepath.cloud_prefix.replace("://", "")
-                )
-            fsspec_filesystem.put(
-                str(localfile),
-                str(storagepath),
-                recursive=True,
-                callback=ProgressCallback(),
-            )
-        else:
-            storagepath.upload_from(localfile)
+    localpath = Path(localpath)
+
+    if localpath.is_file():
+        size = localpath.stat().st_size
     else:
-        try:
-            shutil.copyfile(localfile, storagepath)
-        except shutil.SameFileError:
-            pass
-    size = Path(localfile).stat().st_size
+        size = sum(f.stat().st_size for f in localpath.rglob("*") if f.is_file())
+
+    if isinstance(storagepath, UPath):
+        if localpath.suffix != ".zarr":
+            cb = ProgressCallback()
+        else:
+            # todo: make proper progress bar for zarr
+            cb = fsspec.callbacks.NoOpCallback()
+        storagepath.upload_from(localpath, recursive=True, callback=cb)
+    else:
+        if localpath.is_file():
+            try:
+                shutil.copyfile(localpath, storagepath)
+            except shutil.SameFileError:
+                pass
+        else:
+            if storagepath.exists():
+                shutil.rmtree(storagepath)
+            shutil.copytree(localpath, storagepath)
     return float(size)  # because this is how we store in the db
 
 
@@ -79,11 +78,16 @@ def delete_storage(storagekey: str):
     storagepath = settings.instance.storage.key_to_filepath(storagekey)
     if storagepath.is_file():
         storagepath.unlink()
+    elif storagepath.is_dir():
+        if isinstance(storagepath, UPath):
+            storagepath.rmdir()
+        else:
+            shutil.rmtree(storagepath)
     else:
-        storagepath.rmtree()
+        raise FileNotFoundError(f"{storagepath} is not an existing path!")
 
 
-def load_to_memory(filepath: Union[str, Path], stream: bool = False):
+def load_to_memory(filepath: Union[str, Path, UPath], stream: bool = False):
     """Load a file into memory.
 
     Returns the filepath if no in-memory form is found.
@@ -97,8 +101,9 @@ def load_to_memory(filepath: Union[str, Path], stream: bool = False):
         stream = False
 
     if not stream:
-        # caching happens here if filename is a CloudPath
-        filepath = Path(filepath)
+        # caching happens here if filename is a UPath
+        # todo: make it safe when filepath is just Path
+        filepath = settings.instance.storage.cloud_to_local(filepath)
 
     reader = READER_FUNCS.get(filepath.suffix)
     if reader is None:
