@@ -1,7 +1,8 @@
 import anndata
-import fsspec
 from anndata import AnnData
-from lndb_setup import settings
+from lndb import settings
+
+from ._filesystem import _infer_filesystem
 
 
 def h5ad_to_anndata(filekey) -> AnnData:
@@ -10,8 +11,8 @@ def h5ad_to_anndata(filekey) -> AnnData:
 
 
 def read_adata_h5ad(filepath, **kwargs) -> AnnData:
-    if not isinstance(filepath, str):
-        filepath = str(filepath)
-    with fsspec.open(filepath, mode="rb") as file:
+    fs, filepath = _infer_filesystem(filepath)
+
+    with fs.open(filepath, mode="rb") as file:
         adata = anndata.read_h5ad(file, backed=False, **kwargs)
         return adata
