@@ -1,5 +1,4 @@
 from bionty import lookup as bionty_lookup
-from lnbfx import lookup as lnbfx_lookup
 
 
 class lookup:
@@ -12,7 +11,7 @@ def _get_all_methods(lookup):
     return [i for i in dir(lookup) if not i.startswith("_")]
 
 
-for module in [bionty_lookup, lnbfx_lookup]:
+for module in [bionty_lookup]:
     methods = _get_all_methods(module)
     for method in methods:
         model = getattr(module, method)
